@@ -23,12 +23,11 @@ else:
 	process_tasks(dodo.task_libbirdfont())
 	process_tasks(dodo.make_birdfont_test('birdfont-test', ['libbirdgems.so', 'libbirdfont.so']))
 
-if config.GTK:
-	process_tasks(dodo.task_birdfont())
-	process_tasks(dodo.task_birdfont_autotrace())
-	process_tasks(dodo.task_birdfont_export())
-	process_tasks(dodo.task_birdfont_import())
-	process_tasks(dodo.task_man())
+process_tasks(dodo.task_birdfont())
+process_tasks(dodo.task_birdfont_autotrace())
+process_tasks(dodo.task_birdfont_export())
+process_tasks(dodo.task_birdfont_import())
+process_tasks(dodo.task_man())
 
 compile_translations()
 
